# turmachpy

A lightweight package written for simulating a variety of Turing machines.

## Features

- Custom modules for querying language models like GPT2 on Turing machines.
- Support for running deep neural networks and building nuanced networks on Turing machines' tapes.
- Simplified creation of instances of various kinds of Turing machines like Non-deterministic Turing machines, multi-tape Turing machines etc.
- Decidability of user defined languages over given input.
- Classification of Recursively Enumerable languages of user defined langauges over a set of inputs.
- Capability to run the Universal Turing Machine (A Turing machine that can simulate any other Turing machine, including itself)

With a simple enough import one can create any kind of Turing machine (from those that are available) and once the parameters have been specified, simluation can be function-called.